@@ -10,8 +10,6 @@ baseline_root = 'baseline'
 
 if MPL_VERSION >= LooseVersion('2'):  # pragma: nocover
     baseline_subdir = '2.0.x'
-elif MPL_VERSION >= LooseVersion('1.5'):  # pragma: nocover
-    baseline_subdir = '1.5.x'
 else:  # pragma: nocover
     raise ValueError('Matplotlib {0} is not supported'.format(matplotlib.__version__))
 
